/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2018-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.oauth.microsoft.graph;

import java.util.Collection;
import java.util.Collections;
import org.scribe.builder.api.Api;
import org.scribe.model.Verb;
import com.openexchange.oauth.KnownApi;
import com.openexchange.oauth.api.MicrosoftGraphApi;
import com.openexchange.oauth.impl.AbstractExtendedScribeAwareOAuthServiceMetaData;
import com.openexchange.server.ServiceLookup;

/**
 * {@link MicrosoftGraphOAuthServiceMetaData}
 *
 * @author <a href="mailto:ioannis.chouklis@open-xchange.com">Ioannis Chouklis</a>
 * @since v7.10.2
 */
public class MicrosoftGraphOAuthServiceMetaData extends AbstractExtendedScribeAwareOAuthServiceMetaData {

    private static final String IDENTITY_URL = "https://graph.microsoft.com/v1.0/me";
    private static final String IDENTITY_FIELD_NAME = "id";
    private static final String PROPERTY_IDENTIFIER = "microsoft.graph";

    /**
     * Initialises a new {@link MicrosoftGraphOAuthServiceMetaData}.
     * 
     * @param services The {@link ServiceLookup} instance
     */
    public MicrosoftGraphOAuthServiceMetaData(ServiceLookup services) {
        super(services, KnownApi.MICROSOFT_GRAPH, MicrosoftGraphOAuthScope.values());
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.openexchange.oauth.impl.ScribeAware#getScribeService()
     */
    @Override
    public Class<? extends Api> getScribeService() {
        return MicrosoftGraphApi.class;
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.openexchange.oauth.impl.OAuthIdentityAware#getIdentityURL(java.lang.String)
     */
    @Override
    public String getIdentityURL(String accessToken) {
        return IDENTITY_URL;
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.openexchange.oauth.impl.OAuthIdentityAware#getIdentityHTTPMethod()
     */
    @Override
    public Verb getIdentityHTTPMethod() {
        return Verb.GET;
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.openexchange.oauth.impl.OAuthIdentityAware#getIdentityFieldName()
     */
    @Override
    public String getIdentityFieldName() {
        return IDENTITY_FIELD_NAME;
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.openexchange.oauth.impl.AbstractScribeAwareOAuthServiceMetaData#getPropertyId()
     */
    @Override
    protected String getPropertyId() {
        return PROPERTY_IDENTIFIER;
    }

    /*
     * (non-Javadoc)
     * 
     * @see com.openexchange.oauth.impl.AbstractScribeAwareOAuthServiceMetaData#getExtraPropertyNames()
     */
    @Override
    protected Collection<OAuthPropertyID> getExtraPropertyNames() {
        return Collections.singletonList(OAuthPropertyID.redirectUrl);
    }

}
